netapp_ontap.models.fpolicy_persistent_stores API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fpolicy_persistent_stores`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FpolicyPersistentStoresSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FpolicyPersistentStores object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `autosize_mode: str GET POST`

    Autosize mode for the volume.
    grow ‐ Volume automatically grows in response to the amount of space used.
    grow_shrink ‐ Volume grows or shrinks in response to the amount of space used.
    off ‐ Autosizing of the volume is disabled.

    Valid choices:

    - grow
    - grow_shrink
    - off
  `name: str GET POST`

    The name specified for the FPolicy Persistent Store.

    Example: ps1

  `size: Size GET POST PATCH`

    The size of the Persistent Store volume, in bytes.

    Example: 100M

  `volume: str GET POST PATCH`

    The specified volume to store the events for the FPolicy Persistent Store.

    Example: psvol